pub struct CircuitUpdate {
pub mode: CircuitUpdateMode,
pub compile_count: usize,
pub circuit_fingerprint: u64,
}Expand description
Result of applying an epistemic assumption to a circuit.
Fields
mode: CircuitUpdateModeUpdate mode used by the adapter.
compile_count: usizeNumber of compile operations performed by this circuit state.
circuit_fingerprint: u64Stable circuit fingerprint after the update.