EpistemicProbGpuBatchExecutionEvidence

Struct EpistemicProbGpuBatchExecutionEvidence 

pub struct EpistemicProbGpuBatchExecutionEvidence<'a> {
    pub batch: &'a EpistemicGpuBatchExecutionResult,
    pub assumptions_by_component: &'a [&'a [EpistemicAssumption]],
}
Accepted GPU batch execution evidence used for probabilistic production gating.

Fields

batch: &'a EpistemicGpuBatchExecutionResult

Accepted GPU batch execution result whose aggregate trace and timing must be validated.

assumptions_by_component: &'a [&'a [EpistemicAssumption]]

Epistemic assumptions represented by each accepted component world view.