pub struct EvidenceForcing {
pub force_mask: Vec<u8>,
pub forced_value: Vec<u8>,
pub forceable: bool,
pub reason: ForceabilityReason,
}Expand description
Compiled evidence forcing for the MC sampler.
Fields
force_mask: Vec<u8>Per-variable flag indicating that the sampler must force the variable.
forced_value: Vec<u8>Per-variable Boolean value used when the corresponding mask entry is set.
forceable: boolWhether all evidence can be enforced by direct variable clamping.
reason: ForceabilityReasonExplanation for the forceability decision.