CircuitUpdateMode

Enum CircuitUpdateMode 

pub enum CircuitUpdateMode {
    Unchanged,
    IncrementalEvidence,
    FullRebuild,
}
Circuit update mode for assumption changes.

Variants



Unchanged

Assumption was already active, so no circuit state changed.



IncrementalEvidence

Evidence was updated without rebuilding the compiled circuit.



FullRebuild

The adapter does not support incremental evidence and rebuilt the circuit.