ResidentRejectKind

Enum ResidentRejectKind 

pub enum ResidentRejectKind {
    Negation,
    EpistemicLiteral,
    NonRelationalLiteral,
    ArityTooHigh,
    BodyTooLong,
    TooManyVars,
    UnboundedTerm,
    DomainTooLarge,
    UniverseTooLarge,
    InconsistentArity,
    AnnotatedDisjunctionUnsupported,
}
Kind of a fail-closed rejection of an MC program by the resident engine.

Variants



Negation

A body literal uses negation.



EpistemicLiteral

A body literal is epistemic (know/possible).



NonRelationalLiteral

A body literal is a comparison / arithmetic / univ (non-relational).



ArityTooHigh

A predicate arity exceeds [MAX_ARITY].



BodyTooLong

A rule body has more than [MAX_BODY] literals.



TooManyVars

A rule uses more than [MAX_VARS] distinct variables.



UnboundedTerm

A term is not a variable or ground constant (list/compound/functor/agg).



DomainTooLarge

The bounded domain exceeds [MAX_DOMAIN].



UniverseTooLarge

The bounded universe exceeds [MAX_UNIVERSE].



InconsistentArity

A predicate appears with inconsistent arity.



AnnotatedDisjunctionUnsupported

Annotated disjunctions are not yet supported by the resident engine.

Implementations

Source

impl ResidentRejectKind

pub fn as_str(self) -> &'static str